@@ -1,11 +1,12 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-fgl-5.5.0.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: fgl
-version: 5.4.2.4
-id: fgl-5.4.2.4-61bc70a02df0f4016fdeb5db8e6cfaf9
+version: 5.5.0.1
+id: fgl-5.5.0.1-95bbc373b0cecb4b39689ab2e718bf96
 
 license: BSD3
 copyright:
-maintainer: Ivan.Miljenovic@gmail.com, tomberek@gmail.com
+maintainer: Ivan.Miljenovic@gmail.com
 stability:
 homepage: http://web.engr.oregonstate.edu/~erwig/fgl/haskell
 package-url:
@@ -21,10 +22,9 @@ exposed-modules: Data.Graph.Inductive.Internal.FiniteMap
                  Data.Graph.Inductive.Internal.RootPath
                  Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
                  Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
-                 Data.Graph.Inductive.Graphviz Data.Graph.Inductive.Monad
-                 Data.Graph.Inductive.NodeMap Data.Graph.Inductive.PatriciaTree
-                 Data.Graph.Inductive.Query Data.Graph.Inductive.Tree
-                 Data.Graph.Inductive.Monad.IOArray
+                 Data.Graph.Inductive.Monad Data.Graph.Inductive.NodeMap
+                 Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
+                 Data.Graph.Inductive.Tree Data.Graph.Inductive.Monad.IOArray
                  Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
                  Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
                  Data.Graph.Inductive.Query.Dominators
@@ -33,24 +33,24 @@ exposed-modules: Data.Graph.Inductive.Internal.FiniteMap
                  Data.Graph.Inductive.Query.MaxFlow2
                  Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
                  Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
-hidden-modules:
+hidden-modules: Paths_fgl
 trusted: False
-import-dirs: /usr/local/lib/ghc/fgl-5.4.2.4
-library-dirs: /usr/local/lib/ghc/fgl-5.4.2.4
-hs-libraries: HSfgl-5.4.2.4
+import-dirs: /usr/local/lib/ghc/fgl-5.5.0.1
+library-dirs: /usr/local/lib/ghc/fgl-5.5.0.1
+hs-libraries: HSfgl-5.5.0.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.4.0.1-6380782b62ead58fec616aa07dc0e15c
-         base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
-         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
-         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
+depends: array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-fgl-5.4.2.4/html/fgl.haddock
-haddock-html: /usr/local/share/doc/hs-fgl-5.4.2.4/html
+haddock-interfaces: /usr/local/share/doc/hs-fgl-5.5.0.1/html/fgl.haddock
+haddock-html: /usr/local/share/doc/hs-fgl-5.5.0.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
